@@ -13,10 +13,7 @@
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
-# License along with this program; if not, write to the
-# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
-# Boston, MA 02110-1301, USA.
-# TODO reimplement after GES port
+# License along with this program; if not, see <http://www.gnu.org/licenses/>.
 """Automatic alignment of `Clip`s."""
 import array
 import os
@@ -35,7 +32,7 @@ from gettext import gettext as _
 
 import pitivi.configure as configure
 
-from pitivi.utils.ui import beautify_ETA
+from pitivi.utils.ui import beautify_eta
 from pitivi.utils.misc import call_false
 from pitivi.utils.extract import Extractee
 from pitivi.utils.loggable import Loggable
@@ -250,8 +247,6 @@ def affinealign(reference, targets, max_drift=0.02):
         for i in range(2 * num_blocks):
             halfautocorr[:, i] /= numpy.sqrt(
                 numpy.sum(halfautocorr[:, i] ** 2))
-        # from matplotlib.pyplot import imshow,show
-        # imshow(halfautocorr,interpolation='nearest',aspect='auto');show()
         drift = _findslope(halfautocorr) / bspace
         del halfautocorr
 
@@ -271,16 +266,11 @@ def affinealign(reference, targets, max_drift=0.02):
                 xcorr_blocks[-shift:, i] = xcorr_blocks[:shift, i].copy()
                 xcorr_blocks[:-shift, i] = temp
 
-        # from matplotlib.pyplot import imshow,show
-        # imshow(xcorr_blocks,interpolation='nearest',aspect='auto');show()
-
         # xcorr is the drift-compensated cross-correlation
         xcorr = numpy.sum(xcorr_blocks, axis=1)
         del xcorr_blocks
 
         offset = numpy.argmax(xcorr)
-        # from matplotlib.pyplot import plot,show
-        # plot(xcorr);show()
         del xcorr
         if offset >= len(t):
             offset -= L2
@@ -385,7 +375,7 @@ class ProgressAggregator(ProgressMeter):
         now = time.time()
         remaining = (now - self._start) * (1 - frac) / frac
         for function in self._watchers:
-            function(frac, beautify_ETA(int(remaining * Gst.SECOND)))
+            function(frac, beautify_eta(int(remaining * Gst.SECOND)))
         return False
 
 
@@ -683,9 +673,9 @@ if __name__ == '__main__':
     reference = envelopes[-1]
     offsets, drifts = affinealign(reference, envelopes, 0.02)
     print(offsets, drifts)
-    from matplotlib.pyplot import *
-    clf()
-    for i in range(len(envelopes)):
-        t = offsets[i] + (1 + drifts[i]) * numpy.arange(len(envelopes[i]))
-        plot(t, envelopes[i] / numpy.sqrt(numpy.sum(envelopes[i] ** 2)))
-    show()
+    import matplotlib.pyplot as plt
+    fig, ax = plt.subplots()
+    for o, d, e in zip(offsets, drifts, envelopes):
+        t = o + (1 + d) * numpy.arange(len(e))
+        ax.plot(t, e / numpy.sqrt(numpy.sum(e ** 2)))
+    plt.show()
